@@ -3,7 +3,7 @@ package Code::TidyAll::CacheModel::Shared;
 use Moo;
 extends 'Code::TidyAll::CacheModel';
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 sub _build_cache_key {
     my $self = shift;
@@ -31,13 +31,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::CacheModel::Shared - Shared cache model for Code::TidyAll
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -59,9 +61,12 @@ This allows you to share a cache when you might have several versions of a file
 that you switch backwards and forwards between (e.g. when you're working on
 several branches) and keep the cache values
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -77,7 +82,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
