@@ -2,6 +2,7 @@ package Code::TidyAll::Git::Precommit;
 
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
+use Code::TidyAll::Git::Util qw(git_uncommitted_files);
 use Cwd qw(cwd);
 use File::Slurp::Tiny qw(write_file);
 use Guard;
@@ -10,7 +11,7 @@ use IPC::System::Simple qw(capturex run);
 use Moo;
 use Try::Tiny;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 # Public
 has 'conf_name'       => ( is => 'ro' );
@@ -44,8 +45,7 @@ sub check {
         }
 
         # Gather file paths to be committed
-        my $output = capturex( $self->git_path, "status", "--porcelain" );
-        my @files = grep {-f} ( $output =~ /^[MA]\s+(.*)/gm );
+        my @files = git_uncommitted_files($root_dir);
 
         my $tidyall = $tidyall_class->new_from_conf_file(
             $conf_file,
@@ -54,7 +54,7 @@ sub check {
             mode       => 'commit',
             %{ $self->tidyall_options },
         );
-        my @results = $tidyall->process_paths( map {"$root_dir/$_"} @files );
+        my @results = $tidyall->process_paths(@files);
 
         if ( my @error_results = grep { $_->error } @results ) {
             my $error_count = scalar(@error_results);
@@ -79,6 +79,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Git::Precommit - Git pre-commit hook that requires files to be
@@ -86,7 +88,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -226,9 +228,12 @@ L<here|http://stackoverflow.com/questions/3703159/git-remote-shared-pre-commit-h
 See also L<Code::TidyAll::Git::Prereceive>, which enforces tidyall on pushes to
 a remote shared repository.
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -244,7 +249,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
