@@ -9,7 +9,7 @@ use IPC::System::Simple qw(capturex run);
 use Moo;
 use Try::Tiny;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 # Public
 has 'allow_repeated_push' => ( is => 'ro', default => 3 );
@@ -152,6 +152,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Git::Prereceive - Git pre-receive hook that requires files to be
@@ -159,7 +161,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -314,9 +316,12 @@ input. Returns an error string if there was a problem, undef if no problems.
 This hook will ignore any files with only a single line of content (no
 newlines), as an imperfect way of filtering out symlinks.
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -332,7 +337,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
