@@ -6,7 +6,7 @@ use IPC::Run3 qw(run3);
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 sub validate_params {
     my ( $self, $params ) = @_;
@@ -51,13 +51,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::JSHint - Use jshint with tidyall
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -120,9 +122,12 @@ config file and passed as --config to argv.
 
 =back
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -138,7 +143,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
