@@ -4,7 +4,7 @@ use IPC::Run3;
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 sub _build_cmd {'phpcs'}
 
@@ -28,13 +28,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::PHPCodeSniffer - Use phpcs with tidyall
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -71,9 +73,12 @@ Full path to C<phpcs>
 
 =back
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -89,7 +94,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
