@@ -5,7 +5,7 @@ use Moo::Role;
 use Cwd qw(realpath);
 use File::Temp qw(tempdir);
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 has '_tempdir'   => ( is => 'ro', lazy => 1, builder => 1 );
 has 'no_cleanup' => ( is => 'ro', default => 0 );
@@ -29,6 +29,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Role::Tempdir - Provides a _tempdir attribute for Code::TidyAll
@@ -36,7 +38,7 @@ classes
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -48,8 +50,6 @@ version 0.42
 
 A role to add tempdir attributes to classes.
 
-=encoding UTF-8
-
 =head1 ATTRIBUTES
 
 =over
@@ -65,9 +65,12 @@ should not automatically clean up after itself
 
 =back
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -83,7 +86,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
