@@ -8,7 +8,7 @@ use Moo;
 use SVN::Look;
 use Try::Tiny;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 # Public
 has 'conf_name'                => ( is => 'ro' );
@@ -168,6 +168,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::SVN::Precommit - Subversion pre-commit hook that requires files
@@ -175,7 +177,7 @@ to be tidyall'd
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -308,9 +310,12 @@ Thanks to Alexander Simakov, author of
 L<perlcritic-checker|http://search.cpan.org/~xdr/perlcritic-checker-1.2.6/>,
 for some of the ideas here such as emergency_comment_prefix.
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -326,7 +331,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
