@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 my $test = Test::Builder->new;
 
@@ -82,6 +82,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Code::TidyAll - Check that all your files are tidy and valid according to
@@ -89,7 +91,7 @@ tidyall
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -138,6 +140,13 @@ your config.
 
 L<tidyall>
 
+=head1 SUPPORT
+
+bugs may be submitted through
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -152,7 +161,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
